# Numpyro for GW cosmology

## **CosmoPyro**

CosmoPyro is a Bayesian framework for reconstructing the gravitational-wave population of compact binary coalescences using Hamiltonian Monte Carlo (HMC), and more specifically [NumPyro](https://num.pyro.ai/en/stable/).

## Installation Instructions

### Basic Installation

To create a new environment and install **cosmopyro**, follow these steps:

Either (1) git clone the project from the repository or (2) pip install. 

```bash
conda create -n cosmopyro-env python=3.11
conda activate cosmopyro-env
pip install -e .
```

## Running

For examples, please navigate to the examples folder, and follow the readme there. notebooks in the examples folder.

## Citation

If you use this software, please cite:

[TO WRITE](https://arxiv.org/pdf/??)

```bibtex
@article{
    TOCOLLATE
}
```

## Contact

If you have any questions, feedback, or would like to discuss this project, please don't hesitate to reach out:

Email: Konstantin.Leyde@gmail.com
